/*******************************************************
 Author:          Manfred Langemann
 mailto:          Manfred.Langemann t t-online.de
 Begin of project:      04.01.2008
 Latest version generated:  04.01.2008
 Filename:          Main.c
 Description:          Main routine for testing
               TWI_Master_main.c
 ********************************************************/
#include <stdio.h>
#include <avr/interrupt.h>

#define F_CPU 20000000 

#include "usart.h"
#include "util/delay.h"
#include "TWI_Master.h"
#include <avr/pgmspace.h>


/*
** This main programm demonstrates how to use the 
** implemented TWI master functions. These are:
**  TWIM_Init
**  TWIM_ReadAck
**  TWIM_ReadNack
**  TWIM_Write
**  TWIM_Stop
**
** For testing this program, use the program
** TWI_Slave_main.c in the slave uC and connect the
** two TWI lines properly (don't forget to also
** connect GND between Master and Slave!)
**
** Used uC for Master is ATMega32
*/
int main (void)
  {
 
  uint8_t    j=0;
  //uint8_t    Data[8];
  uint8_t    SlaveAddress = 0x50;
/*
** Clear any interrupt
*/
  cli ();
/*
** Wait 1 second for POR
*/
  _delay_ms (1000);
/*
** Initiate RS232
*/
  usart_init (9600);
  usart_write ("\r\n");
  usart_write ("\r\n");
  usart_write ("Hello world...\r\n");
/*
** Initiate TWI Master Interface with bitrate of 100000 Hz
*/
  if (!TWIM_Init (50000))
    {
    usart_write ("Error in initiating TWI interface\r\n");
    while (1);
    }
/*
** Endless loop
*/
  while (1)
    {
/*
** Write byte(s) to the slave.
** It is implicitely assumed, that the slave will
** accepts 8 bytes
*/
	
      if (!TWIM_Start (SlaveAddress, TWIM_WRITE))
      {
		TWIM_Stop ();
		usart_write ("Could not start TWI Bus for WRITE\r\n");
      }
    else
      {
            TWIM_Write (j);
			usart_write ("Byte sent: %i\r\n", j);
			TWIM_Stop ();
			
			_delay_ms (500);
      }
	j++;
	}
  }

